@@ -35,52 +35,54 @@ int xnestFontPrivateIndex;
 Bool
 xnestRealizeFont(ScreenPtr pScreen, FontPtr pFont)
 {
-  pointer priv;
-  Atom name_atom, value_atom;
-  int nprops;
-  FontPropPtr props;
-  int i;
-  const char *name;
+    void *priv;
+    Atom name_atom, value_atom;
+    int nprops;
+    FontPropPtr props;
+    int i;
+    const char *name;
 
-  FontSetPrivate(pFont, xnestFontPrivateIndex, NULL);
+    FontSetPrivate(pFont, xnestFontPrivateIndex, NULL);
 
-  name_atom = MakeAtom("FONT", 4, True);
-  value_atom = 0L;
+    name_atom = MakeAtom("FONT", 4, True);
+    value_atom = 0L;
 
-  nprops = pFont->info.nprops;
-  props = pFont->info.props;
+    nprops = pFont->info.nprops;
+    props = pFont->info.props;
 
-  for (i = 0; i < nprops; i++)
-    if (props[i].name == name_atom) {
-      value_atom = props[i].value;
-      break;
-    }
+    for (i = 0; i < nprops; i++)
+        if (props[i].name == name_atom) {
+            value_atom = props[i].value;
+            break;
+        }
 
-  if (!value_atom) return False;
+    if (!value_atom)
+        return False;
 
-  name = NameForAtom(value_atom);
+    name = NameForAtom(value_atom);
 
-  if (!name) return False;
+    if (!name)
+        return False;
 
-  priv = (pointer)xalloc(sizeof(xnestPrivFont));  
-  FontSetPrivate(pFont, xnestFontPrivateIndex, priv);
-  
-  xnestFontPriv(pFont)->font_struct = XLoadQueryFont(xnestDisplay, name);
+    priv = (void *) malloc(sizeof(xnestPrivFont));
+    FontSetPrivate(pFont, xnestFontPrivateIndex, priv);
 
-  if (!xnestFontStruct(pFont)) return False;
-						     
-  return True;
+    xnestFontPriv(pFont)->font_struct = XLoadQueryFont(xnestDisplay, name);
+
+    if (!xnestFontStruct(pFont))
+        return False;
+
+    return True;
 }
 
-
 Bool
 xnestUnrealizeFont(ScreenPtr pScreen, FontPtr pFont)
 {
-  if (xnestFontPriv(pFont)) {
-    if (xnestFontStruct(pFont)) 
-      XFreeFont(xnestDisplay, xnestFontStruct(pFont));
-    xfree(xnestFontPriv(pFont));
-    FontSetPrivate(pFont, xnestFontPrivateIndex, NULL);
-  }
-  return True;
+    if (xnestFontPriv(pFont)) {
+        if (xnestFontStruct(pFont))
+            XFreeFont(xnestDisplay, xnestFontStruct(pFont));
+        free(xnestFontPriv(pFont));
+        FontSetPrivate(pFont, xnestFontPrivateIndex, NULL);
+    }
+    return True;
 }
